@@ -46,7 +46,7 @@ class DecisionTreeWriter:
         if type(data_set[0]) == dict:
             data_type_name = "dictionary object"
             data_type = "dict"
-            import_statement = ""
+            import_statement = [""]
         else:
             data_type_name = str(data_set[0].__class__.__name__)
             data_type = data_type_name
@@ -90,18 +90,18 @@ class DecisionTreeWriter:
 
 
     def __validate_tree_name(self, tree_name):
+        errorMessage = "When using a DecisionTreeWriter instance, you asked it to create a model with an invalid name. Please give a valid function name next time."
         i = 0
         for char in tree_name:
             if char not in "1234567890qwertyuiopasdfghjklzxcvbnmQWERTYUIOPASDFGHJKLZXCVBNM_- ":
-                raise Exception("When using a TreeWriter instance, you asked it to create a model with an invalid name. Please give a valid function name next time.")
+                raise Exception(errorMessage)
             
             elif i == 0 and char in "1234567890":
-                raise Exception("When using a TreeWriter instance, you asked it to create a model with an invalid name. Please give a valid function name next time.")
+                raise Exception(errorMessage)
             
             i += 1
 
-        tree_name.replace(" ","_")
-        tree_name.replaxe("-","_")
+        return tree_name.replace(" ","_").replace("-","_")
 
 
     def __build_branch(self, data_set: List[Dict], depth: int, branch_chain: str) -> List[str]:
